@@ -7,8 +7,9 @@ import string
 import typing
 from collections import Counter
 from collections.abc import Iterable
+from pathlib import Path
 
-from .utils import KeyT, _parse_into_words, ensure_unicode, load_file, write_file
+from spellchecker.utils import KeyT, PathOrStr, _parse_into_words, ensure_unicode, load_file, write_file
 
 
 class SpellChecker:
@@ -18,7 +19,7 @@ class SpellChecker:
 
     Args:
         language (str): The language of the dictionary to load or None for no dictionary. Supported languages are \
-            `en`, `es`, `de`, `fr`, `pt`, `ru`, `lv`, and `eu`. Defaults to `en`. A list of languages may be provided and all \
+            `en`, `es`, `de`, `fr`, `pt`, `ru`, `lv`, `eu`, and `nl`. Defaults to `en`. A list of languages may be provided and all \
                 languages will be loaded.
         local_dictionary (str): The path to a locally stored word frequency dictionary; if provided, no language \
             will be loaded
@@ -32,8 +33,8 @@ class SpellChecker:
 
     def __init__(
         self,
-        language: typing.Union[str, typing.Iterable[str]] = "en",
-        local_dictionary: typing.Optional[str] = None,
+        language: typing.Union[str, typing.Iterable[str], None] = "en",
+        local_dictionary: typing.Optional[PathOrStr] = None,
         distance: int = 2,
         tokenizer: typing.Optional[typing.Callable[[str], typing.Iterable[str]]] = None,
         case_sensitive: bool = False,
@@ -53,7 +54,7 @@ class SpellChecker:
             self._word_frequency.load_dictionary(local_dictionary)
         elif language:
             if not isinstance(language, Iterable) or isinstance(language, (str, bytes)):
-                language = [language]  # type: ignore
+                language = [language]
             for lang in language:
                 filename = f"resources/{lang.lower()}.json.gz"
                 try:
@@ -82,7 +83,7 @@ class SpellChecker:
     @classmethod
     def languages(cls) -> typing.Iterable[str]:
         """list: A list of all official languages supported by the library"""
-        return ["de", "en", "es", "fr", "pt", "ru", "ar", "lv", "eu"]
+        return ["de", "en", "es", "fr", "pt", "ru", "ar", "lv", "eu", "nl"]
 
     @property
     def word_frequency(self) -> "WordFrequency":
@@ -122,7 +123,7 @@ class SpellChecker:
         text = ensure_unicode(text)
         return self._tokenizer(text)
 
-    def export(self, filepath: str, encoding: str = "utf-8", gzipped: bool = True) -> None:
+    def export(self, filepath: PathOrStr, encoding: str = "utf-8", gzipped: bool = True) -> None:
         """Export the word frequency list for import in the future
 
         Args:
@@ -281,7 +282,11 @@ class WordFrequency:
         "_longest_word_length",
     ]
 
-    def __init__(self, tokenizer=None, case_sensitive=False):
+    def __init__(
+        self,
+        tokenizer: typing.Optional[typing.Callable[[str], typing.Iterable[str]]] = None,
+        case_sensitive: bool = False
+    ) -> None:
         self._dictionary = Counter()
         self._total_words = 0
         self._unique_words = 0
@@ -330,7 +335,7 @@ class WordFrequency:
 
     @property
     def total_words(self) -> int:
-        """int: The sum of all word occurances in the word frequency dictionary
+        """int: The sum of all word occurrences in the word frequency dictionary
 
         Note:
             Not settable"""
@@ -401,7 +406,7 @@ class WordFrequency:
             This is the same as `dict.items()`"""
         yield from self._dictionary.items()
 
-    def load_dictionary(self, filename: str, encoding: str = "utf-8") -> None:
+    def load_dictionary(self, filename: PathOrStr, encoding: str = "utf-8") -> None:
         """Load in a pre-built word frequency list
 
         Args:
@@ -422,7 +427,7 @@ class WordFrequency:
 
     def load_text_file(
         self,
-        filename: str,
+        filename: PathOrStr,
         encoding: str = "utf-8",
         tokenizer: typing.Optional[typing.Callable[[str], typing.Iterable[str]]] = None,
     ) -> None:
@@ -451,7 +456,7 @@ class WordFrequency:
         if tokenizer:
             words = [x if self._case_sensitive else x.lower() for x in tokenizer(text)]
         else:
-            words = self.tokenize(text)  # type: ignore
+            words = self.tokenize(text)  # type: ignore[assignment]
 
         self._dictionary.update(words)
         self._update_dictionary()
